%define plugin_root /opt/plugins
%define systemd_config_dir /etc/systemd/system
%define lib_root /opt/monitor/op5/check_vmware
%define config_root /etc/op5/check_vmware
%define service_config %{config_root}/service.cfg
%define gunicorn_config %{config_root}/gunicorn.cfg
%define user monitor
%define executable_name check_vmware_v2

Summary: Monitor plugin for running VMware checks
Name: naemon-check-vmware
Version: %{op5version}
Release: %{op5release}%{?dist}
URL: http://www.op5.se
Vendor: OP5 AB
License: OP5 EULA
Group: Applications/Internet

Source: %{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}

BuildRequires: python34

Requires: bash, redis, python34
Requires: op5-monitor-user

%if 0%{?el6}
%description
Monitor plugin for running VMware checks.

The plugin has a service that runs in the background to avoid making a new
HTTP connection to VMware for every check. Before starting the service you
also need to start Redis. Run the commands `service redis start` and
`service check_vmware start`.

For more information about installing and running the plugin, see the README
file.
%else
%description
Monitor plugin for running VMware checks.

The plugin has a service that runs in the background to avoid making a new
HTTP connection to vmware for every check. Before starting the service you
also need to start Redis. Run the commands `systemctl start redis` followed
by `systemctl start check_vmware`. To make sure the services start after a
system reboot, you also need to enable them by running the commands
`systemctl enable redis` and `systemctl enable check_vmware`.

For more information about installing and running the plugin, see the README
file.
%endif

%prep
%setup -q

%{__cat} <<EOF >gunicorn.cfg
"""
See http://docs.gunicorn.org/en/stable/settings.html for documentation on the available
Gunicorn configuration.
"""

bind = 'localhost:8000'
workers = 2
EOF

%{__cat} <<EOF >service.cfg
"""
See README.md for documentation on the available Check VMware service config.

See http://flask.pocoo.org/docs/0.12/config/ for documentation on the available
Flask configuration.

See http://pythonhosted.org/Flask-Caching/#configuring-flask-caching for
documentation on the available Flask-Caching configuration.
"""

EOF
# Magic line to copy existing defaults from config.py, commented.
%{__awk} '/^#/ { f = 1 } f' check_vmware/service/config.py | %{__awk} '/^[A-Za-z_]/ {print "#" $0; next} 1' >>service.cfg

%install
export LC_ALL=en_US.UTF-8
/usr/bin/python3.4 -m venv venv
venv/bin/pip install pipenv wheel
venv/bin/python setup.py bdist_wheel
venv/bin/pipenv lock -r > requirements.txt
venv/bin/pip download -r requirements.txt -d dist
%{__tar} cvfz dist.tar.gz dist

%{__rm} -rf %{buildroot}
%{__mkdir} -p %{buildroot}%{lib_root}
%{__mkdir} -p %{buildroot}%{config_root}
%{__install} -Dp -m0644 dist.tar.gz %{buildroot}%{lib_root}/dist.tar.gz
%{__cp} -R vsan_sdk %{buildroot}%{lib_root}/vsan_sdk
%{__install} -Dp -m0644 README.md %{buildroot}%{lib_root}/README.md
%{__install} -Dp -m0644 LICENSE.txt %{buildroot}%{lib_root}/LICENSE.txt
%{__install} -Dp -m0644 Pipfile %{buildroot}%{lib_root}/Pipfile
%{__install} -Dp -m0644 Pipfile.lock %{buildroot}%{lib_root}/Pipfile.lock
%{__install} -Dp -m0755 setup.py %{buildroot}%{lib_root}/setup.py
%{__install} -Dp -m0644 MANIFEST.in %{buildroot}%{lib_root}/MANIFEST.in
%{__install} -Dp -m0755 check_vmware_v2 %{buildroot}%{plugin_root}/%{executable_name}
%{__install} -Dp -m0644 gunicorn.cfg %{buildroot}%{config_root}/gunicorn.cfg
%{__install} -Dp -m0644 service.cfg %{buildroot}%{config_root}/service.cfg
%if 0%{?el6}
%{__install} -Dp -m0755 check_vmware.init %{buildroot}%{_sysconfdir}/init.d/check_vmware
%else
%{__install} -Dp -m0644 check_vmware.service %{buildroot}%{systemd_config_dir}/check_vmware.service
%endif

%post
cd %{lib_root}
%{__rm} -rf dist venv
%{__tar} xvfz dist.tar.gz
/usr/bin/python3.4 -m venv venv
venv/bin/pip install --upgrade -f dist --no-index dist/check_vmware-*.whl
%{__chown} -R %{user} .

# start and enable
%if 0%{?el6}
# Check if a pid file with the old path exists, in that case move it so
# that the service commands don't lose track of it. This check can be
# removed when we are confident no one uses the old pid file anymore...
pidfile=/var/run/check_vmware/check_vmware.pid
oldpidfile=/var/run/check_vmware.pid
if [ -f $oldpidfile ]; then
    if [ -f $pidfile ]; then
        rm $oldpidfile
    else
        mkdir -p `dirname $pidfile`
        mv $oldpidfile $pidfile
    fi
fi
service redis start
service check_vmware start
%else
systemctl daemon-reload
systemctl start redis
systemctl start check_vmware
%endif

%if 0%{?el6}
chkconfig --add redis
chkconfig --level 345 redis on
chkconfig --add check_vmware
%else
systemctl enable redis
systemctl enable check_vmware
%endif

%postun
%if 0%{?el6}
if [ "$1" -ge "1" ] ; then
    /sbin/service check_vmware condrestart >/dev/null 2>&1 || :
fi
%else
%systemd_postun_with_restart check_vmware.service
%endif

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, %{user}, root, 0755)
%doc %{lib_root}/README.md
%doc %{lib_root}/LICENSE.txt
%{plugin_root}/%{executable_name}
%{lib_root}/dist.tar.gz
%{lib_root}/vsan_sdk
%{lib_root}/setup.py
%{lib_root}/MANIFEST.in
%{lib_root}/Pipfile
%{lib_root}/Pipfile.lock
%if 0%{?el6}
%config(noreplace) %attr(755, root, root) %{_sysconfdir}/init.d/check_vmware
%else
%config(noreplace) %attr(664, root, root) %{systemd_config_dir}/check_vmware.service
%endif
%config(noreplace) %{config_root}/gunicorn.cfg
%config(noreplace) %attr(600, %{user}, root) %{config_root}/service.cfg
%exclude %{lib_root}/setup.pyc
%exclude %{lib_root}/setup.pyo

%changelog
* Tue Feb 5 2019 Petter Nyström <support@op5.com> - v0.1.16
- Package dependencies in install step for offline installation
* Tue Jan 22 2019 Petter Nyström <support@op5.com> - v0.1.15
- Remove plugin metadata file, it will be added to the plugins-metadata repo instead.
* Mon Jan 7 2019 Petter Nyström <support@op5.com> - v0.1.14
- Run the Gunicorn service as the monitor user, not root
* Thu Jul 19 2018 Jacob Hansen <support@op5.com> - v0.1.11
- Start the check_vmware service after install and at boot
* Tue Jul 10 2018 Petter Nyström <support@op5.com> - v0.1.10
- Install config files under /etc/op5/check_vmware
* Mon Jul 9 2018 Petter Nyström <support@op5.com> - v0.1.9
- Use python3.4 on both EL6 and EL7
* Thu Jun 28 2018 Petter Nyström <support@op5.com> - v0.1.8
- Add LICENSE.txt file
* Tue Mar 6 2018 Petter Nyström <support@op5.com> - v0.1.5
- Use pipenv to sync version dependencies
* Thu Mar 1 2018 Petter Nyström <support@op5.com> - v0.1.5
- Use config(noreplace) macro instead of config
* Tue Feb 13 2018 Petter Nyström <support@op5.com> - v0.0.10
- Install init script in /etc/init.d/ instead of /etc/init
* Tue Jan 16 2018 Petter Nyström <support@op5.com> - v0.0.6
- Install check_vmware command
* Mon Jan 8 2018 Erik Mellegård <support@op5.com> - v0.0.4
- Add project to CI pipeline (needs some tweaking)
* Mon Jan 8 2018 Erik Mellegård <support@op5.com> - v0.0.3
- Add plugin metadata file. Add requirements. Set 2 workers as default for service.
* Thu Jan 4 2018 Erik Mellegård <support@op5.com> - v0.0.2
- Add shell script that calls virtualenv python executable, so that help text in monitor displays correct help text
* Tue Jan 2 2018 Erik Mellegård <support@op5.com> - v0.0.1
- Initial attempt.
